==> qtjambi-uic-5.15.11-sources.jar: io/qt/uic/ui4/DomColorRole.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomColorRole</p>
 */
public class DomColorRole extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomColorRole(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomColorRole instance);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeRole(){
        return attributeRole_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeRole_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeRole(){
        clearAttributeRole_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeRole_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementBrush(){
        clearElementBrush_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementBrush_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomBrush elementBrush(){
        return elementBrush_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomBrush elementBrush_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeRole(){
        return hasAttributeRole_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeRole_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementBrush(){
        return hasElementBrush_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementBrush_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeRole(java.lang.String a){
        setAttributeRole_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeRole_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementBrush(io.qt.uic.ui4.DomBrush a){
        setElementBrush_native_DomBrush_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementBrush_native_DomBrush_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomBrush takeElementBrush(){
        return takeElementBrush_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomBrush takeElementBrush_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomColorRole(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-5.15.17-sources.jar: io/qt/uic/ui4/DomColorRole.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomColorRole</code></p>
 */
public class DomColorRole extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomColorRole::<wbr>DomColorRole()</code></p>
     */
    public DomColorRole(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomColorRole instance);
    
    /**
     * <p>See <code>DomColorRole::<wbr>attributeRole()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeRole(){
        return attributeRole_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeRole_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomColorRole::<wbr>clearAttributeRole()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeRole(){
        clearAttributeRole_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeRole_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomColorRole::<wbr>clearElementBrush()</code></p>
     */
    @QtUninvokable
    public final void clearElementBrush(){
        clearElementBrush_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementBrush_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomColorRole::<wbr>elementBrush()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomBrush elementBrush(){
        return elementBrush_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomBrush elementBrush_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomColorRole::<wbr>hasAttributeRole()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeRole(){
        return hasAttributeRole_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeRole_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomColorRole::<wbr>hasElementBrush()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementBrush(){
        return hasElementBrush_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementBrush_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomColorRole::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomColorRole::<wbr>setAttributeRole(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeRole(java.lang.@NonNull String a){
        setAttributeRole_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeRole_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomColorRole::<wbr>setElementBrush(DomBrush*)</code></p>
     */
    @QtUninvokable
    public final void setElementBrush(io.qt.uic.ui4.@Nullable DomBrush a){
        setElementBrush_native_DomBrush_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementBrush_native_DomBrush_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomColorRole::<wbr>takeElementBrush()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomBrush takeElementBrush(){
        return takeElementBrush_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomBrush takeElementBrush_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomColorRole::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomColorRole(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}
